"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Endpoint = void 0;
const lisk_sdk_1 = require("lisk-sdk");
const utils_1 = require("./utils");
class Endpoint extends lisk_sdk_1.BasePluginEndpoint {
    load(store) {
        this._chainConnectorStore = store;
    }
    async getSentCCUs(_context) {
        const sentCCUs = await this._chainConnectorStore.getListOfCCUs();
        return sentCCUs.map(transaction => new lisk_sdk_1.chain.Transaction(transaction).toJSON());
    }
    async getAggregateCommits(_context) {
        const aggregateCommits = await this._chainConnectorStore.getAggregateCommits();
        return aggregateCommits.map(aggregateCommit => (0, utils_1.aggregateCommitToJSON)(aggregateCommit));
    }
    async getBlockHeaders(_context) {
        const blockHeaders = await this._chainConnectorStore.getBlockHeaders();
        return blockHeaders.map(blockHeader => new lisk_sdk_1.BlockHeader(blockHeader).toJSON());
    }
    async getCrossChainMessages(_context) {
        const ccmsAndInclusionProofs = await this._chainConnectorStore.getCrossChainMessages();
        return ccmsAndInclusionProofs.map(ccmsAndInclusionProof => (0, utils_1.ccmsFromEventsToJSON)(ccmsAndInclusionProof));
    }
    async getLastSentCCM(_context) {
        const lastSentCCM = await this._chainConnectorStore.getLastSentCCM();
        if (!lastSentCCM) {
            throw new Error('No CCM was sent so far.');
        }
        return {
            ...lastSentCCM,
            fee: lastSentCCM.fee.toString(),
            height: lastSentCCM.height,
            receivingChainID: lastSentCCM.receivingChainID.toString('hex'),
            sendingChainID: lastSentCCM.sendingChainID.toString('hex'),
            nonce: lastSentCCM.nonce.toString(),
            params: lastSentCCM.params.toString('hex'),
        };
    }
    async getValidatorsInfoFromPreimage(_context) {
        const validatorsHashPreimage = await this._chainConnectorStore.getValidatorsHashPreimage();
        return (0, utils_1.validatorsHashPreimagetoJSON)(validatorsHashPreimage);
    }
}
exports.Endpoint = Endpoint;
//# sourceMappingURL=endpoint.js.map